.. _ext-frontends:

*******************
Frontend extensions
*******************

Here you can find a list of external packages that extend Mopidy with
additional frontends, which includes just about anything that use the
:ref:`core-api`.

This list is moderated and updated on a regular basis. If you want your package
to show up here, follow the :ref:`guide on creating extensions <extensiondev>`.


Mopidy-HTTP
===========

Bundled with Mopidy. See :ref:`ext-http`.


Mopidy-MPD
==========

Bundled with Mopidy. See :ref:`ext-mpd`.


Mopidy-MPRIS
============

https://github.com/mopidy/mopidy-mpris

Extension for controlling Mopidy through the `MPRIS <http://www.mpris.org/>`_
D-Bus interface, for example using the Ubuntu Sound Menu.


Mopidy-Notifier
===============

https://github.com/sauberfred/mopidy-notifier

Extension for displaying track info as User Notifications in Mac OS X.


Mopidy-Scrobbler
================

https://github.com/mopidy/mopidy-scrobbler

Extension for scrobbling played tracks to Last.fm.


Mopidy-Touchscreen
==================

https://github.com/9and3r/mopidy-touchscreen

Extension for displaying track info and controlling Mopidy from a touch screen
using `PyGame <http://www.pygame.org/>`_/SDL.
